MapEntity

Struct MapEntity 

pub struct MapEntity<T: Entity> {
    pub id: Integer,
    pub x: Float,
    pub y: Float,
    pub width: Option<Integer>,
    pub height: Option<Integer>,
    pub origin_x: Float,
    pub origin_y: Float,
    pub entity: T,
}
The full struct of an Entity implementaiton

These fields are on every entity element and are useful even when we cannot resolve the entity itself

Fields

id: Integerx: Floaty: Floatwidth: Option<Integer>height: Option<Integer>origin_x: Floatorigin_y: Floatentity: T